From ae7de06ce1a285960c5c77955f66fb30a88a828c Mon Sep 17 00:00:00 2001
From: shipmints <shipmints@gmail.com>
Date: Mon, 16 Dec 2024 11:36:27 -0500
Subject: [PATCH] Support pixelwise frame cloning (bug#74750)

* lisp/frame.el (clone-frame):
Honor frame-resize-pixelwise when cloning a frame's geometry
via make-frame text-pixel feature.
Correctly specify source frame in display-graphic-p test for
tty selection behavior.
---
 lisp/frame.el | 14 ++++++++++++--
 1 file changed, 12 insertions(+), 2 deletions(-)

diff --git a/lisp/frame.el b/lisp/frame.el
index 1b5aa8cff08..02f3f9f9dae 100644
--- a/lisp/frame.el
+++ b/lisp/frame.el
@@ -863,3 +863,6 @@ make-frame-command
 (defun clone-frame (&optional frame no-windows)
   "Make a new frame with the same parameters and windows as FRAME.
 With a prefix arg NO-WINDOWS, don't clone the window configuration.
+If the user option `frame-resize-pixelwise' is non-nil, and FRAME is
+graphical, clone the originating frame's pixel size.  Otherwise, use
+the number of FRAME's columns and lines for the clone.

 FRAME defaults to the selected frame.  The frame is created on the
 same terminal as FRAME.  If the terminal is a text-only terminal then
@@ -875,10 +878,17 @@ clone-frame
           (seq-remove (lambda (elem)
                         (memq (car elem) frame-internal-parameters))
                       (frame-parameters frame)))
-         (new-frame (make-frame)))
+         new-frame)
+    (when (and frame-resize-pixelwise
+               (display-graphic-p frame))
+      (push (cons 'width (cons 'text-pixels (frame-text-width frame)))
+            default-frame-alist)
+      (push (cons 'height (cons 'text-pixels (frame-text-height frame)))
+            default-frame-alist))
+    (setq new-frame (make-frame))
     (when windows
       (window-state-put windows (frame-root-window new-frame) 'safe))
-    (unless (display-graphic-p)
+    (unless (display-graphic-p frame)
       (select-frame new-frame))
     new-frame))

--
2.47.1
